<?php

namespace Drupal\toolshed\Strategy;

use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Factory that injects the service container when creating strategy instances.
 */
class ContainerStrategyFactory implements StrategyFactoryInterface {

  /**
   * The dependency injection container to use with strategy constructors.
   *
   * @var \Symfony\Component\DependencyInjection\ContainerInterface
   */
  protected ContainerInterface $container;

  /**
   * Creates a new instance of the ContainerStrategyFactory class.
   */
  public function __construct() {
    $this->container = \Drupal::getContainer();
  }

  /**
   * {@inheritdoc}
   */
  public function create(string $id, StrategyDefinitionInterface $definition): StrategyInterface {
    $class = $definition->getClass();

    if (is_subclass_of($class, ContainerInjectionStrategyInterface::class)) {
      return $class::create($this->container, $id, $definition);
    }

    return new $class($id, $definition);
  }

}
