<?php

namespace Drupal\toolshed\Strategy;

/**
 * The base class for Strategy implementations.
 *
 * The base class provides helps to expose the strategy definition properties
 * and helps to ease the implementation of the StrategyInterface.
 */
abstract class StrategyBase implements StrategyInterface {

  /**
   * The Strategy identifier.
   *
   * @var string
   */
  protected $id;

  /**
   * The definition for this strategy.
   *
   * @var \Drupal\toolshed\Strategy\StrategyDefinitionInterface
   */
  protected StrategyDefinitionInterface $definition;

  /**
   * {@inheritdoc}
   */
  public function id(): string {
    return $this->id;
  }

  /**
   * {@inheritdoc}
   */
  public function getProvider(): string {
    return $this->definition->getProvider();
  }

  /**
   * {@inheritdoc}
   */
  public function getProviderType(): string {
    return $this->definition->getProviderType();
  }

  /**
   * {@inheritdoc}
   */
  public function getDefinition(): StrategyDefinitionInterface {
    return $this->definition;
  }

}
