<?php

namespace Drupal\toolshed\Strategy;

/**
 * The default the strategy definition.
 */
class StrategyDefinition implements StrategyDefinitionInterface {

  /**
   * The identifier for this strategy.
   *
   * @var string
   */
  protected string $id;

  /**
   * The provider of the strategy definition.
   *
   * @var string
   */
  protected string $provider;

  /**
   * The provider type (module or theme).
   *
   * @var string
   */
  protected string $providerType;

  /**
   * The fully namespaced class for the strategy.
   *
   * @var string
   */
  protected string $class;

  /**
   * The strategy definition data.
   *
   * @var mixed[]
   */
  protected array $data;

  /**
   * Creates a new instance of the StrategyDefinition class.
   *
   * @param string $id
   *   The strategy identifier.
   * @param mixed[] $definition
   *   The strategy definition found from the discovery.
   */
  public function __construct(string $id, array $definition) {
    $this->id = $id;
    $this->class = $definition['class'];
    $this->provider = $definition['provider'];
    $this->providerType = $definition['provider_type'] ?? 'module';

    $this->data = $definition;
  }

  /**
   * {@inheritdoc}
   */
  public function id(): string {
    return $this->id;
  }

  /**
   * {@inheritdoc}
   */
  public function getClass(): string {
    return $this->class;
  }

  /**
   * {@inheritdoc}
   */
  public function setClass(string $class): void {
    $this->class = $class;
  }

  /**
   * {@inheritdoc}
   */
  public function getProvider(): string {
    return $this->provider;
  }

  /**
   * {@inheritdoc}
   */
  public function getProviderType(): string {
    return $this->providerType;
  }

  /**
   * PHP magic method to get other strategy definition data.
   *
   * @param string $key
   *   The property name to fetch the definition data value for.
   *
   * @return mixed|null
   *   The value matching the $key if there is a property value. NULL if there
   *   is no value for a matching property.
   */
  public function __get(string $key) {
    return $this->data[$key] ?? NULL;
  }

}
